@@ -232,22 +232,19 @@ class RowToRipe():
         return t, y
 
 
-    def fourier(x,y,axis=-1,detrend=True,zeroPadding=0,cycleExtension=1,window='boxcar'):
+    def fourier(self,x,y,axis=-1,detrend=True,zeroPadding=0,cycleExtension=1,window='boxcar'):
         '''
-        
+
         x: linear time array or sample_rate
         y: 1d or 2d array 
         axis: FFT along the axis
         detrend: detrend the offset of y if True ,default True.
         zeroPadding: append zero for y along the axis
         cycleExtension: cycleExtend y along the axis
-        window: str or tuple or array_like, optional
-                Desired window to use. If window is a string or tuple, 
+        window: str or tuple. Desired window to use. 
                 it is passed to get_window to generate the window values, 
                 which are DFT-even by default. See get_window for a list of 
-                windows and required parameters. If window is array_like it will 
-                be used directly as the window and its length must be nperseg. 
-                Defaults to a Hann window.
+                windows and required parameters. Defaults to a boxcar window.
         '''
         
         y = signal.detrend(y,axis=axis,type='constant') if detrend else y
@@ -1265,9 +1262,12 @@ class Bessel_fit(RowToRipe):
 #         self.tstart = 0
 
 #     def fitfunc(t, p):
-#         return (t >= 0) *(p[0] + np.sum(p[1::2,None]*np.exp(-p[2::2,None]*t[None,:]), axis=0))
-#     def errfunc(p):
-#         return (fitfunc(data[:,0], p) - data[:,1])*(1.0+0.5*scipy.special.erf(0.4*(data[:,0]-tCut)))**5
+#         return (t >= 0) * ( np.sum(p[1::2,None]*(np.exp(-p[2::2,None]*(t[None,:]+tp))-np.exp(-p[2::2,None]*t[None,:]))/p[2::2,None], axis=0)) 
+#     def errfunc(p,t,phi):
+#         return (fitfunc(t, p)* height * diff_height -phi )*(1.0+0.5*scipy.special.erf(0.4*(t-buffer)))**10
+
+#     def err(p,t,phi):
+#         return np.sum(errfunc(p,t,phi)**2)
 
 #     p0 = np.zeros(2*timeconstants+1)
 #     p0[1::2] = -np.linspace(0, 0.02, timeconstants)
